@@ -21,10 +21,10 @@ av_reify(AV *av)
     I32 key;
     SV* sv;
 
-    if (AvREAL(av))                           
-	return;          
+    if (AvREAL(av))
+	return;
 #ifdef DEBUGGING
-    if (SvRMAGICAL(av) && mg_find((SV*)av,'P')) 
+    if (SvRMAGICAL(av) && mg_find((SV*)av,'P'))
 	warn("av_reify called on tied array");
 #endif
     key = AvMAX(av) + 1;
@@ -369,7 +369,6 @@ av_undef(register AV *av)
 	    SvREFCNT_dec(AvARRAY(av)[--key]);
     }
     Safefree(AvALLOC(av));
-    SvPVX(av) = 0;
     AvALLOC(av) = 0;
     SvPVX(av) = 0;
     AvMAX(av) = AvFILLp(av) = -1;
@@ -479,7 +478,7 @@ av_unshift(register AV *av, register I32 num)
 	AvFILLp(av) += i;
 	SvPVX(av) = (char*)(AvARRAY(av) - i);
     }
-    if (num) {     
+    if (num) {
 	i = AvFILLp(av);
 	av_extend(av, i + num);
 	AvFILLp(av) += num;
