@@ -68,6 +68,7 @@ PERLVAR(Iscreamfirst,	I32 *)
 PERLVAR(Iscreamnext,	I32 *)		
 PERLVARI(Imaxscream,	I32,	-1)	
 PERLVAR(Ilastscream,	SV *)		
+PERLVAR(Ireplgv,	GV *)		
 
 /* shortcuts to misc objects */
 PERLVAR(Ierrgv,		GV *)		
@@ -161,14 +162,13 @@ PERLVAR(Isys_intern,	struct interp_intern)		/* platform internals */
 #endif
 
 /* more statics moved here */
-PERLVAR(Imh,		HE)		/* from hv.c */
 PERLVARI(Igeneration,	int,	100)	/* from op.c */
 PERLVAR(IDBcv,		CV *)		/* from perl.c */
 PERLVAR(Iarchpat_auto,	char*)		/* from perl.c */
 PERLVAR(Isortcxix,	I32)		/* from pp_ctl.c */
 PERLVAR(Ilastgotoprobe,	OP*)		/* from pp_ctl.c */
 PERLVAR(Iregdummy,	regnode)	/* from regcomp.c */
-PERLVAR(Iregparse,	char*)		/* Input-scan pointer. */
+PERLVAR(Iregcomp_parse,	char*)		/* Input-scan pointer. */
 PERLVAR(Iregxend,	char*)		/* End of input for compile */
 PERLVAR(Iregcode,	regnode*)	/* Code-emit pointer; &regdummy = don't. */
 PERLVAR(Iregnaughty,	I32)		/* How bad is this pattern? */
@@ -182,12 +182,12 @@ PERLVAR(Iregflags,	U16)		/* are we folding, multilining? */
 
 PERLVAR(Iregseen,	U32)		/* from regcomp.c */
 PERLVAR(Iseen_zerolen,	I32)		/* from regcomp.c */
-PERLVAR(Irx,		regexp *)	/* from regcomp.c */
+PERLVAR(Iregcomp_rx,	regexp *)	/* from regcomp.c */
 PERLVAR(Iextralen,	I32)		/* from regcomp.c */
-#ifdef DEBUGGING
+/* #ifdef DEBUGGING -- keep the structure the same with/without DEBUGGING defined */
 PERLVAR(Icolorset,	int)		/* from regcomp.c */
 PERLVAR(Icolors[4],	char *)		/* from regcomp.c */
-#endif 
+/* #endif */
 
 PERLVAR(Ireginput,	char *)		/* String-input pointer. */
 PERLVAR(Iregbol,	char *)		/* Beginning of input, for ^ check. */
@@ -205,11 +205,11 @@ PERLVAR(Ibostr,		char *)		/* from regexec.c */
 PERLVAR(Ireg_flags,	U32)		/* from regexec.c */
 PERLVAR(Ireg_eval_set,	I32)		/* from regexec.c */
 
-#ifdef DEBUGGING
+/* #ifdef DEBUGGING -- keep the structure the same with/without DEBUGGING defined */
 PERLVAR(Iregnarrate,	I32)		/* from regexec.c */
 PERLVAR(Iregprogram,	regnode *)	/* from regexec.c */
 PERLVARI(Iregindent,	int,	    0)	/* from regexec.c */
-#endif
+/* #endif */
 
 PERLVAR(Iregcc,		CURCUR *)	/* from regexec.c */
 PERLVARI(Iin_clean_objs,bool,	    FALSE)  /* from sv.c */
