@@ -25,11 +25,6 @@ PERLVARI(Gthreadsv_names,	char *,	THREADSV_NAMES)
 PERLVAR(Gcurthr,	struct perl_thread *)	/* Currently executing (fake) thread */
 #endif
 #endif /* USE_THREADS */
-#ifdef PERL_OBJECT
-#ifdef WIN32
-PERLVAR(Gerror_no,    int)	/* errno for each interpreter */
-#endif
-#endif
 
 PERLVAR(Guid,	int)		/* current real user id */
 PERLVAR(Geuid,	int)		/* current effective user id */
@@ -112,7 +107,6 @@ PERLVAR(Gmulti_end,	I32)		/* last line of multi-line string */
 PERLVAR(Gmulti_open,	I32)		/* delimiter of said string */
 PERLVAR(Gmulti_close,	I32)		/* delimiter of said string */
 
-PERLVAR(Gscrgv,	GV *)		
 PERLVAR(Gerror_count,	I32)		/* how many errors so far, max 10 */
 PERLVAR(Gsubline,	I32)		/* line this subroutine began on */
 PERLVAR(Gsubname,	SV *)		/* name of current subroutine */
@@ -173,3 +167,5 @@ PERLVARIC(GNo,		char *, "")
 PERLVARIC(Ghexdigit,	char *, "0123456789abcdef0123456789ABCDEFx")
 PERLVARIC(Gpatleave,	char *, "\\.^$@dDwWsSbB+*?|()-nrtfeaxc0123456789[{]}")
 
+PERLVAR(Gspecialsv_list[4], SV *)		/* from byterun.h */
+
