@@ -76,8 +76,8 @@ PP(pp_regcomp) {
     MAGIC *mg = Null(MAGIC*);
 
     tmpstr = POPs;
-    if(SvROK(tmpstr)) {
-	SV *sv = SvRV(tmpstr);
+    if(SvROK(tmpstr) || SvRMAGICAL(tmpstr)) {
+	SV *sv = SvROK(tmpstr) ? SvRV(tmpstr) : tmpstr;
 	if(SvMAGICAL(sv))
 	    mg = mg_find(sv, 'r');
     }
@@ -101,6 +101,7 @@ PP(pp_regcomp) {
 
 	    pm->op_pmflags = pm->op_pmpermflags;	/* reset case sensitivity */
 	    pm->op_pmregexp = pregcomp(t, t + len, pm);
+	    sv_magic(tmpstr,(SV*)ReREFCNT_inc(pm->op_pmregexp),'r',0,0);
 	}
     }
 
@@ -1773,7 +1774,7 @@ PP(pp_goto)
 		}
 		else {
 		    stack_sp--;		/* There is no cv arg. */
-		    (void)(*CvXSUB(cv))(cv _THIS);
+		    (void)(*CvXSUB(cv))(cv _PERL_OBJECT_THIS);
 		}
 		LEAVE;
 		return pop_return();
